# equit-ease
Access up-to-date price data for any of your favorite stocks from the command line

## Who is this Project For?
This project is for you If you enjoy following day-to-day movements in the market, want to stay up-to-date on the latest price trends, and spend a majority of your time working in the terminal.

## Getting Started
### Installation
Currently, you can install the CLI with `brew` or `pip`.
### With Brew
Initial Installation:
```shell
>>> brew tap danmurphy1217/equit-ease
>>> brew install danmurphy1217/equit-ease/equit-ease
```
Installing Updates:
```shell
>>> brew tap danmurphy1217/equit-ease
>>> brew upgrade danmurphy1217/equit-ease/equit-ease
```
### With Pip
```shell
>>> python3 -m venv venv # setup virtual env...
>>> source venv/bin/activate 
>>> pip install EquitEase
```
### Verifying Installation
```shell
>>> equity --version # or equity -v
```
